@@ -5,6 +5,7 @@ from base64 import urlsafe_b64decode
 import requests
 from requests.exceptions import HTTPError
 from flask import Request, jsonify, abort
+from . import util
 
 
 MEDIATOR_URL = os.environ["MEDIATOR_URL"]
@@ -70,10 +71,6 @@ def _trim_document_path(path):
     return "/".join(path.split("/")[5:])
 
 
-def repo_name(wid, cid):
-    return "{}-{}".format(wid, cid)
-
-
 class Asset:
     def __init__(self, path):
         self.path = path
@@ -91,13 +88,15 @@ class ParsedRequest:
         data = request.json
         self.user_info = user_info(request)
         self.data = data
-        self.repo = repo_name(data.get("wid"), data.get("cid"))
-        self.change_ref = "{}/{}/{}".format(
+        self.repo = util.repo_name(data.get("wid"), data.get("cid"))
+        self.change_ref = util.change_ref(
             data.get("sid"), self.user_info.get("user_id"), data.get("change_id")
         )
-        self.plan_ref = "tf/plan/{}".format(self.change_ref)
-        self.apply_ref = "tf/apply/{}".format(data.get("sid"))
-        self.source_apply_ref = "tf/apply/{}".format(data.get("source_sid"))
+        self.plan_ref = util.plan_ref(
+            data.get("sid"), self.user_info.get("user_id"), data.get("change_id")
+        )
+        self.apply_ref = self.apply_ref(data.get("sid"))
+        self.source_apply_ref = self.apply_ref(data.get("source_sid"))
 
 
 class DBEvent:
